@@ -39,7 +39,7 @@ def initContext():
         taskId=sys.argv[1]
         global TASKINFOREPLACE
         inputPath = sys.path[0] + "/input" + "/" + taskId + "/input.log"
-        data=open(inputPath,encoding='utf -8').read()
-        params=json.loads(data)
+        data=open(inputPath,encoding='utf-8').read()
+        params=data
     taskInfo=json.loads(params)
     contextObj=context(taskInfo)
